@@ -26,13 +26,12 @@
 #include <glib-object.h>
 
 G_BEGIN_DECLS
-
 /**
- * TYPE_DMAP_MDNS_BROWSER:
+ * DMAP_TYPE_MDNS_BROWSER:
  *
  * The type for #DMAPMdnsBrowser.
  */
-#define TYPE_DMAP_MDNS_BROWSER         (dmap_mdns_browser_get_type ())
+#define DMAP_TYPE_MDNS_BROWSER         (dmap_mdns_browser_get_type ())
 /**
  * DMAP_MDNS_BROWSER:
  * @o: Object which is subject to casting.
@@ -41,21 +40,21 @@ G_BEGIN_DECLS
  * Depending on the current debugging level, this function may invoke
  * certain runtime checks to identify invalid casts.
  */
-#define DMAP_MDNS_BROWSER(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_DMAP_MDNS_BROWSER, DMAPMdnsBrowser))
+#define DMAP_MDNS_BROWSER(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), DMAP_TYPE_MDNS_BROWSER, DMAPMdnsBrowser))
 /**
  * DMAP_MDNS_BROWSER_CLASS:
  * @k: a valid #DMAPMdnsBrowserClass
  *
  * Casts a derived #DAAPShareClass structure into a #DAAPShareClass structure.
  */
-#define DMAP_MDNS_BROWSER_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), TYPE_DMAP_MDNS_BROWSER, DMAPMdnsBrowserClass))
+#define DMAP_MDNS_BROWSER_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), DMAP_TYPE_MDNS_BROWSER, DMAPMdnsBrowserClass))
 /**
  * IS_DMAP_MDNS_BROWSER:
- * @o: Instance to check for being a %TYPE_DMAP_MDNS_BROWSER.
+ * @o: Instance to check for being a %DMAP_TYPE_MDNS_BROWSER.
  *
- * Checks whether a valid #GTypeInstance pointer is of type %TYPE_DAAP_SHARE.
+ * Checks whether a valid #GTypeInstance pointer is of type %DAAP_TYPE_SHARE.
  */
-#define IS_DMAP_MDNS_BROWSER(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_DMAP_MDNS_BROWSER))
+#define IS_DMAP_MDNS_BROWSER(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), DMAP_TYPE_MDNS_BROWSER))
 /**
  * IS_DMAP_MDNS_BROWSER_CLASS:
  * @k: a #DMAPMdnsBrowserClass
@@ -63,7 +62,7 @@ G_BEGIN_DECLS
  * Checks whether @k "is a" valid #DMAPMdnsBrowserClass structure of type
  * %DMAP_MDNS_BROWSER or derived.
  */
-#define IS_DMAP_MDNS_BROWSER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_DMAP_MDNS_BROWSER))
+#define IS_DMAP_MDNS_BROWSER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), DMAP_TYPE_MDNS_BROWSER))
 /**
  * DMAP_MDNS_BROWSER_GET_CLASS:
  * @o: a #DMAPMdnsBrowser instance.
@@ -72,60 +71,78 @@ G_BEGIN_DECLS
  *
  * Returns: pointer to object class structure.
  */
-#define DMAP_MDNS_BROWSER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_DMAP_MDNS_BROWSER, DMAPMdnsBrowserClass))
-
-typedef struct _DMAPMdnsBrowser        DMAPMdnsBrowser;
-typedef struct _DMAPMdnsBrowserClass   DMAPMdnsBrowserClass;
+#define DMAP_MDNS_BROWSER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), DMAP_TYPE_MDNS_BROWSER, DMAPMdnsBrowserClass))
+typedef struct _DMAPMdnsBrowser DMAPMdnsBrowser;
+typedef struct _DMAPMdnsBrowserClass DMAPMdnsBrowserClass;
 typedef struct _DMAPMdnsBrowserPrivate DMAPMdnsBrowserPrivate;
 typedef struct _DMAPMdnsBrowserService DMAPMdnsBrowserService;
 
 typedef enum
 {
-    DMAP_MDNS_BROWSER_SERVICE_TYPE_INVALID = 0,
-    DMAP_MDNS_BROWSER_SERVICE_TYPE_DAAP,
-    DMAP_MDNS_BROWSER_SERVICE_TYPE_DPAP,
-    DMAP_MDNS_BROWSER_SERVICE_TYPE_DACP,
-    DMAP_MDNS_BROWSER_SERVICE_TYPE_LAST = DMAP_MDNS_BROWSER_SERVICE_TYPE_DACP
+	DMAP_MDNS_BROWSER_SERVICE_TYPE_INVALID = 0,
+	DMAP_MDNS_BROWSER_SERVICE_TYPE_DAAP,
+	DMAP_MDNS_BROWSER_SERVICE_TYPE_DPAP,
+	DMAP_MDNS_BROWSER_SERVICE_TYPE_DACP,
+	DMAP_MDNS_BROWSER_SERVICE_TYPE_RAOP,
+	DMAP_MDNS_BROWSER_SERVICE_TYPE_LAST = DMAP_MDNS_BROWSER_SERVICE_TYPE_RAOP
 } DMAPMdnsBrowserServiceType;
 
+// FIXME: this is only for RAOP and corresponds to the "tp" txt record.
+// This should be in a sub-class.
+typedef enum
+{
+	DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_TCP = 0,
+	DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_UDP,
+	DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_LAST = DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_UDP
+} DMAPMdnsBrowserTransportProtocol;
+
+static const char * const service_type_name[] = {
+	NULL,
+	"_daap._tcp",
+	"_dpap._tcp",
+	"_touch-remote._tcp",
+	"_raop._tcp"
+};
+
 typedef enum
 {
-    DMAP_MDNS_BROWSER_ERROR_NOT_RUNNING = 0,
-    DMAP_MDNS_BROWSER_ERROR_FAILED,
+	DMAP_MDNS_BROWSER_ERROR_NOT_RUNNING = 0,
+	DMAP_MDNS_BROWSER_ERROR_FAILED,
 } DMAPMdnsBrowserError;
 
 struct _DMAPMdnsBrowserService
 {
-    gchar *service_name;
-    gchar *name;
-    gchar *host;
-    guint port;
-    gboolean password_protected;
-    gchar *pair;
+	gchar *service_name;
+	gchar *name;
+	gchar *host;
+	guint port;
+	gboolean password_protected;
+	gchar *pair;                                         // FIXME: subclass
+	DMAPMdnsBrowserTransportProtocol transport_protocol; // FIXME: subclass
 };
 
 struct _DMAPMdnsBrowserClass
 {
-    GObjectClass parent_class;
+	GObjectClass parent_class;
 
-    void (* service_added)    (DMAPMdnsBrowser *browser,
-                               DMAPMdnsBrowserService *service);
-    void (* service_removed ) (DMAPMdnsBrowser *browser,
-                               DMAPMdnsBrowserService *service);
+	void (*service_added) (DMAPMdnsBrowser * browser,
+			       DMAPMdnsBrowserService * service);
+	void (*service_removed) (DMAPMdnsBrowser * browser,
+				 DMAPMdnsBrowserService * service);
 };
 
 struct _DMAPMdnsBrowser
 {
-    GObject object;
+	GObject object;
 
-    DMAPMdnsBrowserPrivate *priv;
+	DMAPMdnsBrowserPrivate *priv;
 };
 
 #define DMAP_MDNS_BROWSER_ERROR dmap_mdns_browser_error_quark ()
 
-GQuark                     dmap_mdns_browser_error_quark      (void);
+GQuark dmap_mdns_browser_error_quark (void);
 
-GType                      dmap_mdns_browser_get_type         (void);
+GType dmap_mdns_browser_get_type (void);
 
 /**
  * dmap_mdns_browser_new:
@@ -135,7 +152,7 @@ GType                      dmap_mdns_browser_get_type         (void);
  *
  * Returns: a pointer to a DMAPMdnsBrowser.
  */
-DMAPMdnsBrowser           *dmap_mdns_browser_new              (DMAPMdnsBrowserServiceType type);
+DMAPMdnsBrowser *dmap_mdns_browser_new (DMAPMdnsBrowserServiceType type);
 
 /**
  * dmap_mdns_browser_start:
@@ -146,8 +163,8 @@ DMAPMdnsBrowser           *dmap_mdns_browser_new              (DMAPMdnsBrowserSe
  *
  * Returns: TRUE on success, else FALSE.
  */
-gboolean                   dmap_mdns_browser_start            (DMAPMdnsBrowser *browser,
-                                                               GError **error);
+gboolean dmap_mdns_browser_start (DMAPMdnsBrowser * browser, GError ** error);
+
 /**
  * dmap_mdns_browser_stop:
  * @browser: A DMAPMdnsBrowser.
@@ -157,12 +174,12 @@ gboolean                   dmap_mdns_browser_start            (DMAPMdnsBrowser *
  *
  * Returns: TRUE on success, else FALSE.
  */
-gboolean                   dmap_mdns_browser_stop             (DMAPMdnsBrowser *browser,
-                                                               GError **error);
+gboolean dmap_mdns_browser_stop (DMAPMdnsBrowser * browser, GError ** error);
 
-G_CONST_RETURN GSList     *dmap_mdns_browser_get_services     (DMAPMdnsBrowser *browser);
-DMAPMdnsBrowserServiceType dmap_mdns_browser_get_service_type (DMAPMdnsBrowser *browser);
+G_CONST_RETURN GSList *dmap_mdns_browser_get_services (DMAPMdnsBrowser *
+						       browser);
+DMAPMdnsBrowserServiceType dmap_mdns_browser_get_service_type (DMAPMdnsBrowser
+							       * browser);
 
 G_END_DECLS
-
 #endif
